% Example 3.4
% 
% Copyright 2015 Ali N. Akansu and Mustafa U. Torun
%
% A Primer for Financial Engineering
% Financial Signal Processing and Electronic Trading
%

clc; clear all; close all;

% Given values
P = [1 0.6 0.2; 0.6 1 0.7; 0.2 0.7 1];
SIGMA = diag([0.02, 0.03, 0.01]);
C = SIGMA' * P * SIGMA;
MU = [0.07;0.03; 0.02];
ONE = [1; 1; 1];

% Plot Markowitz bullet
target_mus = 0.00:.0001:0.07;
risk_at_target_mus = zeros(size(target_mus));
for i=1:length(target_mus)
    target_mu = target_mus(i);
    a = MU' / C * MU;
    b = ONE' / C * MU;
    c = MU' / C * ONE;
    d = ONE' / C * ONE;
    opt_q = (det([target_mu b; 1 d]) * (C\MU) + ...
        det([a target_mu ; c 1]) * (C\ONE)) / ...
        det([a b; c d]);
    risk_at_target_mus(i) = sqrt(opt_q' * C * opt_q);
end
hold on
plot(risk_at_target_mus, target_mus, 'k');

% CML
rf = 0.015;
temp = C \ (MU - ONE * rf);
qm = temp / sum(temp);
mu_m = qm' * MU;
sigma_m =sqrt(qm' * C * qm);
cm_line = (target_mus - rf)/(mu_m - rf)*sigma_m;
arbitrary_line = (target_mus - rf)/(0.036 - rf) * 0.0104;
plot(cm_line, target_mus, 'k-.');
plot(0, rf, 'ko');
plot(sigma_m, mu_m, 'kv');
plot(arbitrary_line, target_mus, 'k--');

% Set figure limits and label axes
xlim([0 0.015])
ylim([0.01 0.08])
ylabel('\mu')
xlabel('\sigma')
legend('Markowitz Bullet', ...
    'Capital Market Line', ...
    'Risk-Free Asset', ...
    'Market Portfolio', ...
    'location', 'northWest')