% Example 3.3
% 
% Copyright 2015 Ali N. Akansu and Mustafa U. Torun
%
% A Primer for Financial Engineering
% Financial Signal Processing and Electronic Trading
%

clc; clear all; close all;

% Given values
P = [1 0.6 0.2; 0.6 1 0.7; 0.2 0.7 1];
SIGMA = diag([0.02, 0.03, 0.01]);
C = SIGMA' * P * SIGMA;
MU = [0.07;0.03; 0.02];
ONE = [1; 1; 1];

% Plot attainable portfolios
N = 1000;
ret = zeros(N,1);
risk = zeros(N,1);
for i=1:N
    q = randn(3,1);
    q = q / sum(q);
    ret(i) = q' * MU;
    risk(i) = sqrt(q' * C * q);
end
plot(risk,ret,'k.')

% Plot Markowitz bullet
target_mus = 0.00:.0001:0.07;
risk_at_target_mus = zeros(size(target_mus));
for i=1:length(target_mus)
    target_mu = target_mus(i);
    a = MU' / C * MU;
    b = ONE' / C * MU;
    c = MU' / C * ONE;
    d = ONE' / C * ONE;
    opt_q = (det([target_mu b; 1 d]) * (C\MU) + ...
        det([a target_mu ; c 1]) * (C\ONE)) / ...
        det([a b; c d]);
    risk_at_target_mus(i) = sqrt(opt_q' * C * opt_q);
end
hold on
plot(risk_at_target_mus, target_mus, 'k');

% Plot minimum risk portfolio
q_minrisk = (C \ ONE) / (ONE' / C * ONE);
mu_minrisk = q_minrisk' * MU;
risk_minrisk = sqrt(q_minrisk' * C * q_minrisk);
plot(risk_minrisk, mu_minrisk, 'ks')

% Set figure limits and label axes
xlim([0 0.015])
ylim([0.01 0.08])
ylabel('\mu')
xlabel('\sigma')
legend('Attainable Portfolios', ...
    'Markowitz Bullet', ...
    'Min. Risk Portfolio', ...
    'location', 'northWest')