% Simple moving average (SMA) and exponential moving average (EMA)
%
% Copyright 2015 Ali N. Akansu and Mustafa U. Torun
%
% A Primer for Financial Engineering
% Financial Signal Processing and Electronic Trading
%

clear all; close all; clc;

% Parameters
N1 = 20;
N2 = 50;
alpha = 2 / (N1 + 1);

% Load data
load Data
p = Adjusted_Price_AAPL;
timestamp = datenum(Dates);

% SMA
sma1 = filter(ones(1,N1)/N1, 1, p);
sma2 = filter(ones(1,N2)/N2, 1, p);

% EMA
ema = filter(alpha, [1 -(1-alpha)], p);

% Plot and label
plot(timestamp, p, 'k')
hold on
plot(timestamp(N1:end), sma1(N1:end), 'k--')
plot(timestamp(N2:end), sma2(N2:end), 'k-.')
plot(timestamp(N1:end), ema(N1:end), 'k:')
datetick('x', 'mmmyy');
axis tight
ylim([min(p) max(p)])
legend('Price', ...
    'SMA (N=20)', ...
    'SMA (N=50)', ...
    'EMA (\alpha=0.095)', ...
    'location', 'NorthWest');
ylabel('USD');