% Example 6.4
% 
% Copyright 2015 Ali N. Akansu and Mustafa U. Torun
%
% A Primer for Financial Engineering
% Financial Signal Processing and Electronic Trading
%

clc; clear all; close all;

% Parameters
S0 = 60;                   % Initial price
x0 = 1e6;                  % Number of shares we own
N = 10;                    % Number of intervals
sigma = 0.05/sqrt(252)*S0; % Volatilitly
epsilon = 0.01;            % Bid-Ask Spread
gamma = 0.01/(0.1*5*1e6);  % Permanent Impact
eta = 0.01/(0.01*5*1e6);   % Temporary Impact
lambdas = [1e-5 1e-6 realmin]; % Risk Aversion Parameter

% Calculate trajectory for different risk aversion parameters
kappas = sqrt(lambdas * sigma^2 / eta);
interval = 0:N;
x = zeros(length(kappas), length(interval));
for i = 1:length(kappas)
    x(i,:) = x0 * sinh( kappas(i) * (N - interval)) ./ sinh(kappas(i) * N);
end

% Plot and label
styles = {'k-*','k-s','k-o'};
for i = 1:length(kappas)
    plot(interval, x(i,:), styles{i});
    hold on;
end
xlim([0 10])
ylim([0 1e6])
legend('\lambda=10^{-5}', '\lambda=10^{-6}', '\lambda=0')
xlabel('n')
ylabel('x(n)')