% A recipe for pairs trading
%
% Copyright 2015 Ali N. Akansu and Mustafa U. Torun
%
% A Primer for Financial Engineering
% Financial Signal Processing and Electronic Trading
%

clear all; close all; clc;

% Thresholds
T1 = 1.0; % Threshold for enter
T2 = 0.5; % Threshold for exit

% Load data and calculate return processes
load Data
p1 = Adjusted_Price_AAPL;
p2 = Adjusted_Price_QQQ;
N = length(p1);
r1 = get_return(p1, 'same_size');
r2 = get_return(p2, 'same_size');

% Regress r1 on r2
[beta,beta_int,epsilon] = regress(r1, [ones(N,1) r2]);

% Calculate the spread and the normalized spread
spread = cumsum(epsilon);
spread_n = (spread - mean(spread)) / std(spread);

% Generate the signals
pos = NO_POSITION * ones(N,1);
signal = zeros(N,1);
for n = 2:N
    if pos(n-1) == NO_POSITION && spread_n(n) > T1
        signal(n) = SHORT_SELL;
        pos(n) = SHORT;
    elseif pos(n-1) == NO_POSITION && spread_n(n) < -T1
        signal(n) = BUY;
        pos(n) = LONG;
    elseif pos(n-1) == SHORT && spread_n(n) < T2
        signal(n) = BUY_TO_COVER;
        pos(n) = NO_POSITION;
    elseif pos(n-1) == LONG && spread_n(n) > -T2
        signal(n) = SELL;
        pos(n) = NO_POSITION;
    else
        pos(n) = pos(n-1);
    end
end

% Plot and label
subplot 211
plot(datenum(Dates), spread_n);
hold on
plot(datenum(Dates),  T1 * ones(size(spread_n)), 'r');
plot(datenum(Dates),  T2 * ones(size(spread_n)), 'k');
plot(datenum(Dates), -T2 * ones(size(spread_n)), 'k');
plot(datenum(Dates), -T1 * ones(size(spread_n)), 'r');
datetick('x')
ylabel('Spread')

subplot 212
stairs(datenum(Dates), pos);
datetick('x')
ylabel('Position')