function sigma_p = risk_hedged(q, vol, lambda, PHI, L, g, beta, sigma_h)
% RISK_HEDGED Calculates risk of a hedged portfolio using eigenfiltered
% empirical correlation matrix of asset returns
%
% q is N x 1 quantity
% vol is N x 1 volatility
% lambda is N x 1 eigenvalues
% PHI is the N X N eigenmatirx where each column is an eigenvector
% L is the number of factors
% 
% Copyright 2015 Ali N. Akansu and Mustafa U. Torun
%
% A Primer for Financial Engineering
% Financial Signal Processing and Electronic Trading
%
sigma_p = 0;
temp = zeros(size(q));
for k = 1:L
    sigma_p = sigma_p + lambda(k) * (sum(q .* PHI(:,k) .* vol) + sum(g .* beta(:,k))).^2;
    temp = temp + lambda(k) * PHI(:,k) .* PHI(:,k);
end
epsilon = 1 - temp;
sigma_p = sigma_p + sum(epsilon.^2 .* q.^2 .* vol.^2);
sigma_p = sigma_p + sum(sigma_h .* g'.^2);
end
