% A recipe for trend following
%
% Copyright 2015 Ali N. Akansu and Mustafa U. Torun
%
% A Primer for Financial Engineering
% Financial Signal Processing and Electronic Trading
%

clear all; close all; clc;

% Parameters
L = 20;

% Load data
load Data
p = Adjusted_Price_AAPL;
N = length(p);

% SMA
SMA = filter(ones(1,L) / L, 1, p);

% Generate signals
pos = NO_POSITION * ones(N,1);
signal = zeros(N,1);
for n = L+1:N
    if pos(n-1) == NO_POSITION && p(n) < SMA(n)
        signal(n) = SHORT_SELL;
        pos(n) = SHORT;
    elseif pos(n-1) == NO_POSITION && p(n) > SMA(n)
        signal(n) = BUY;
        pos(n) = LONG;
    elseif pos(n-1) == SHORT && p(n) > SMA(n)
        signal(n) = BUY_TO_COVER;
        pos(n) = NO_POSITION;
    elseif pos(n-1) == LONG && p(n) < SMA(n)
        signal(n) = SELL;
        pos(n) = NO_POSITION;
    else
        pos(n) = pos(n-1);
    end
end

% Plot and label
subplot 211
plot(datenum(Dates(L+1:N)), p(L+1:N));
hold on
plot(datenum(Dates(L+1:N)), SMA(L+1:N), 'r');
datetick('x')
ylabel('USD')

subplot 212
stairs(datenum(Dates(L+1:N)), pos(L+1:N));
datetick('x')
ylabel('Position')